@@ -23,7 +23,7 @@ makeAlpine01Function = function(dimensions) {
       id = "x",
       lower = rep(-10, dimensions),
       upper = rep(10, dimensions),
-      vector = FALSE
+      vector = TRUE
     ),
     tags = attr(makeAlpine01Function, "tags"),
     global.opt.params = rep(0, dimensions),
@@ -34,4 +34,4 @@ makeAlpine01Function = function(dimensions) {
 class(makeAlpine01Function) = c("function", "smoof_generator")
 attr(makeAlpine01Function, "name") = c("Alpine01 Function")
 attr(makeAlpine01Function, "type") = c("single-objective")
-attr(makeAlpine01Function, "tags") = c("continuous", "non-differentiable", "separable", "non-scalable", "multimodal")
+attr(makeAlpine01Function, "tags") = c("continuous", "non-differentiable", "separable", "scalable", "multimodal")
