@@ -24,8 +24,9 @@ makeAlpine02Function = function(dimensions) {
       id = "x",
       lower = rep(0, dimensions),
       upper = rep(10, dimensions),
-      vector = FALSE
+      vector = TRUE
     ),
+    minimize = FALSE,
     tags = attr(makeAlpine02Function, "tags"),
     global.opt.params = rep(7.917, dimensions),
     global.opt.value = 2.808^dimensions
