@@ -23,7 +23,7 @@ makeChungReynoldsFunction = function(dimensions) {
       id = "x",
       lower = rep(-100, dimensions),
       upper = rep(100, dimensions),
-      vector = FALSE
+      vector = TRUE
     ),
     tags = attr(makeChungReynoldsFunction, "tags"),
     global.opt.params = rep(0, dimensions),
