@@ -20,7 +20,7 @@ makeLeonFunction = function() {
       id = "x",
       lower = c(-1.2, -1.2),
       upper = c(1.2, 1.2),
-      vector = FALSE
+      vector = TRUE
     ),
     tags = attr(makeLeonFunction, "tags"),
     global.opt.params = c(1, 1),
