@@ -1,6 +1,6 @@
 #' Matyas Function
 #'
-#' Two-dimensiona, unimodal test function
+#' Two-dimensional, unimodal test function
 #' \deqn{f(\mathbf{x}) = 0.26 (\mathbf{x}_1^2 + \mathbf{x}_2^2) - 0.48\mathbf{x}_1\mathbf{x}_2}
 #' subject to \eqn{\mathbf{x}_i \in [-10, 10], i = 1, 2}.
 #'
@@ -19,7 +19,7 @@ makeMatyasFunction = function() {
       id = "x",
       lower = c(-10, -10),
       upper = c(10, 10),
-      vector = FALSE
+      vector = TRUE
     ),
     tags = attr(makeMatyasFunction, "tags"),
     global.opt.params = c(0, 0),
