@@ -24,7 +24,7 @@ makePowellSumFunction = function(dimensions) {
       id = "x",
       lower = rep(-1, dimensions),
       upper = rep(1, dimensions),
-      vector = FALSE
+      vector = TRUE
     ),
     tags = attr(makePowellSumFunction, "tags"),
     global.opt.params = rep(0, dimensions),
