@@ -26,7 +26,7 @@ makeRastriginFunction = function(dimensions) {
       id = "x",
       lower = rep(-5.12, dimensions),
       upper = rep(5.12, dimensions),
-      vector = FALSE
+      vector = TRUE
     ),
     tags = attr(makeRastriginFunction, "tags"),
     global.opt.params = rep(0, dimensions),
@@ -37,4 +37,4 @@ makeRastriginFunction = function(dimensions) {
 class(makeRastriginFunction) = c("function", "smoof_generator")
 attr(makeRastriginFunction, "name") = c("Rastrigin Function")
 attr(makeRastriginFunction, "type") = c("single-objective")
-attr(makeRastriginFunction, "tags") = c("multimodal", "continuous", "separable")
+attr(makeRastriginFunction, "tags") = c("multimodal", "continuous", "separable", "scalable")
