@@ -23,7 +23,7 @@ makeSphereFunction = function(dimensions) {
       id = "x",
       lower = rep(-5.12, dimensions),
       upper = rep(5.12, dimensions),
-      vector = FALSE
+      vector = TRUE
     ),
     tags = attr(makeSphereFunction, "tags"),
     global.opt.params = rep(0, dimensions),
