@@ -21,7 +21,7 @@ makeThreeHumpCamelFunction = function() {
       id = "x",
       lower = c(-5, -5),
       upper = c(5, 5),
-      vector = FALSE
+      vector = TRUE
     ),
     tags = attr(makeThreeHumpCamelFunction, "tags"),
     global.opt.params = c(0, 0),
